macro_rules! decode_via_parse {
($ty:ty, $code:path) => { ... };
}Expand description
Generate a Decode impl that adapts an existing Ty::parse(frame) -> Option<Ty>.
macro_rules! decode_via_parse {
($ty:ty, $code:path) => { ... };
}Generate a Decode impl that adapts an existing Ty::parse(frame) -> Option<Ty>.